@@ -14,11 +14,11 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '1.51';
+our $VERSION = '1.60';
 
 my $settings = undef;
 
-sub _load_db_settings { $settings = plugin_setting; }
+sub _load_db_settings { $settings = plugin_setting(); }
 
 my %handles;
 # Hashref used as key for default handle, so we don't have a magic value that
@@ -97,6 +97,8 @@ register database => sub {
     }
 };
 
+Dancer::Factory::Hook->instance->install_hooks(qw(database_connected));
+
 register_plugin;
 
 # Given the settings to use, try to get a database connection
@@ -104,8 +106,8 @@ sub _get_connection {
     my $settings = shift;
 
     # Assemble the DSN:
-    my $dsn;
-    my $driver;
+    my $dsn = '';
+    my $driver = '';
     if ($settings->{dsn}) {
         $dsn = $settings->{dsn};
         ($driver) = $dsn =~ m{dbi:([^:]+)};
@@ -175,6 +177,8 @@ sub _get_connection {
         }
     }
 
+    Dancer::Factory::Hook->instance->execute_hooks('database_connected', $dbh);
+
     # Indicate whether queries generated by quick_query() etc in
     # Dancer::Plugin::Database::Handle should be logged or not; this seemed a
     # little dirty, but DBI's docs encourage it
@@ -447,6 +451,32 @@ Examples:
   database->quick_select($table_name, {});
 
 
+=head1 HOOKS
+
+This plugin uses Dancer's hooks support to allow you to register code that
+should execute at given times - for example:
+
+    hook 'database_connected' => sub {
+        my $dbh = shift;
+        # do something with the new DB handle here
+    };
+
+Currrently defined hook positions are:
+
+=over 4
+
+=item C<database_connected>
+
+Called when a new database connection has been established, after performing any
+C<on_connect_do> statements, but before the handle is returned.  Receives the
+new database handle as a parameter, so that you can do what you need with it.
+
+=back
+
+If you need other hook positions which would be useful to you, please feel free
+to suggest them!
+
+
 =head1 AUTHOR
 
 David Precious, C<< <davidp@preshweb.co.uk> >>
@@ -495,6 +525,10 @@ James Aitken (LoonyPandora)
 
 Mark Allen (mrallen1)
 
+Sergiy Borodych (bor)
+
+Mario Domgoergen (mdom)
+
 
 =head1 BUGS
 
